ImageEditorState class

Inheritance

Constructors

ImageEditorState()

Properties

addTextController ↔ TextEditingController
getter/setter pair
allowGenerateText ↔ ValueNotifier<bool>
getter/setter pair
appBarHeight ↔ double
getter/setter pair
availableColors ↔ List
getter/setter pair
ballSize ↔ double
getter/setter pair
boldCurrentText ↔ ValueNotifier<bool>
getter/setter pair
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
currentDegrees ↔ ValueNotifier<double>
getter/setter pair
currentText ↔ ValueNotifier<String>
getter/setter pair
currentTextOffset ↔ ValueNotifier<Offset>
getter/setter pair
draggedHeight ↔ ValueNotifier<double>
getter/setter pair
draggedLeft ↔ ValueNotifier<double>
getter/setter pair
draggedTop ↔ ValueNotifier<double>
getter/setter pair
draggedWidth ↔ ValueNotifier<double>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
iconsListHeight ↔ ValueNotifier<double>
getter/setter pair
imageHeight ↔ ValueNotifier<double>
getter/setter pair
imageWidth ↔ ValueNotifier<double>
getter/setter pair
inputsNotEmpty ↔ ValueNotifier<bool>
getter/setter pair
limitCroppedSize ↔ double
getter/setter pair
lineColor ↔ Color
getter/setter pair
linesHeight ↔ double
getter/setter pair
linesWidth ↔ double
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
prevAngle ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
widget → EditImageComponentState
The current configuration.
no setterinherited
widgetKey ↔ GlobalKey<State<StatefulWidget>>
getter/setter pair

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
AddTextComponent(dynamic child, EditImageProvider editImageProvider) → Widget
build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createImagePng(BuildContext context, EditImageProvider editImageProvider) → Future<void>
cropRectangleComponent(dynamic child, EditImageProvider editImageProvider) → Widget
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
inherited
didUpdateWidget(covariant EditImageComponentState oldWidget) → void
Called whenever the widget configuration changes.
inherited
dispose() → void
Called when this object is removed from the tree permanently.
inherited
generateCanvas(ImageInfo? imageInfo, EditImageProvider editImageProvider, BuildContext context) → Widget
getLeft(double left) → double
getTop(double top2) → double
initState() → void
Called when this object is inserted into the tree.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDrag(double dx, double dy) → void
paintCanvasComponent(dynamic child, EditImageProvider editImageProvider) → Widget
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
showAddTextPopup(BuildContext context, double degrees, EditImageProvider editImageProvider) → void
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited